@@ -1,22 +1,10 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
 
-   Copyright (c) 2000,2001 Dawit Alemayehu <adawit@kde.org>
-   Copyright (c) 2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Lesser General Public
-   License (LGPL) as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
-
-   You should have received a copy of the GNU Lesser General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef KHistoryComboBoxBOX_H
@@ -25,10 +13,14 @@
 #include <kcombobox.h>
 #include <kcompletion_export.h>
 
+#include <functional>
+
 class KPixmapProvider;
 class KHistoryComboBoxPrivate;
 
 /**
+ * @class KHistoryComboBox khistorycombobox.h KHistoryComboBox
+ *
  * @short A combobox for offering a history and completion
  *
  * A combobox which implements a history like a unix shell. You can navigate
@@ -43,7 +35,7 @@ class KHistoryComboBoxPrivate;
  * duplicates will be disabled when HISTCONTROL is set to "ignoredups" or
  * "ignoreboth". Otherwise, duplicates are enabled by default.
  *
- * \image html khistorycombobox.png "KDE History Combo Box"
+ * \image html khistorycombobox.png "KHistoryComboBox widget"
  *
  * @author Carsten Pfeiffer <pfeiffer@kde.org>
  */
@@ -74,20 +66,20 @@ public:
      *
      * @p parent the parent object of this widget.
      */
-    explicit KHistoryComboBox(QWidget *parent = 0);
+    explicit KHistoryComboBox(QWidget *parent = nullptr);
 
     /**
     * Same as the previous constructor, but additionally has the option
     * to specify whether you want to let KHistoryComboBox handle completion
-    * or not. If set to @p true, KHistoryComboBox will sync the completion to the
+    * or not. If set to @c true, KHistoryComboBox will sync the completion to the
     * contents of the combobox.
     */
-    explicit KHistoryComboBox(bool useCompletion, QWidget *parent = 0);
+    explicit KHistoryComboBox(bool useCompletion, QWidget *parent = nullptr);
 
     /**
      * Destructs the combo, the completion-object and the pixmap-provider
      */
-    ~KHistoryComboBox();
+    ~KHistoryComboBox() override;
 
     /**
      * Inserts @p items into the combobox. @p items might get
@@ -101,7 +93,7 @@ public:
      * Inserts @p items into the combobox. @p items might get
      * truncated if it is longer than maxCount()
      *
-     * Set @p setCompletionList to true, if you don't have a list of
+     * Set @c setCompletionList to true, if you don't have a list of
      * completions. This tells KHistoryComboBox to use all the items for the
      * completion object as well.
      * You won't have the benefit of weighted completion though, so normally
@@ -131,7 +123,7 @@ public:
      * Be sure to use different names for saving with KConfig if you have more
      * than one KHistoryComboBox.
      *
-     * Note: When @p setCompletionList is true, the items are inserted into the
+     * Note: When @c setCompletionList is true, the items are inserted into the
      * KCompletion object with mode KCompletion::Insertion and the mode is set
      * to KCompletion::Weighted afterwards.
      *
@@ -153,12 +145,13 @@ public:
     /**
      * Removes all items named @p item.
      *
-     * @return @p true if at least one item was removed.
+     * @return @c true if at least one item was removed.
      *
      * @see addToHistory
      */
     bool removeFromHistory(const QString &item);
 
+#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(5, 66)
     /**
      * Sets a pixmap provider, so that items in the combobox can have a pixmap.
      * KPixmapProvider is just an abstract class with the one pure virtual
@@ -167,18 +160,32 @@ public:
      * own custom pixmaps, or use the KUrlPixmapProvider from KIO,
      * which uses KMimeType::pixmapForUrl to resolve icons.
      *
-     * Set @p provider to Q_NULLPTR if you want to disable pixmaps. Default no pixmaps.
+     * Set @p provider to nullptr if you want to disable pixmaps. Default no pixmaps.
      *
      * @see pixmapProvider
+     * @deprecated since 5.66, use setIconProvider
      */
+    KCOMPLETION_DEPRECATED_VERSION(5, 66, "Use setIconProvider")
     void setPixmapProvider(KPixmapProvider *provider);
+#endif
 
+#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(5, 66)
     /**
      * @returns the current pixmap provider.
      * @see setPixmapProvider
      * @see KPixmapProvider
+     * @deprecated since 5.66, unused
      */
+    KCOMPLETION_DEPRECATED_VERSION(5, 66, "unused")
     KPixmapProvider *pixmapProvider() const;
+#endif
+
+    /**
+     * Sets an icon provider, so that items in the combobox can have an icon.
+     * The provider is a function that takes a QString and returns a QIcon
+     * @since 5.66
+     */
+    void setIconProvider(std::function<QIcon(const QString &)> providerFunction);
 
     using QComboBox::insertItems;
 
@@ -225,12 +232,12 @@ protected:
     /**
      * Handling key-events, the shortcuts to rotate the items.
      */
-    void keyPressEvent(QKeyEvent *) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent *) override;
 
     /**
      * Handling wheel-events, to rotate the items.
      */
-    void wheelEvent(QWheelEvent *ev) Q_DECL_OVERRIDE;
+    void wheelEvent(QWheelEvent *ev) override;
 
     /**
      * Inserts @p items into the combo, honoring pixmapProvider()
